==> siconv-0.1.1.1.tar.gz: siconv-0.1.1.1/siconv/util_array.py <==
charactors = {
    'අ': 'a', 'ඉ': 'i', 'ඊ': 'ii', 'උ': 'u', 'ඍ': 'Ru', 'එ': 'e', 'ඔ': 'o', 'ක': 'k', 'ග': 'g', 'ච': 'ch',
    'ජ': 'j', 'ට': 't', 'ඩ': 'd', 'න': 'n', 'ප': 'p', 'බ': 'b', 'ල' : 'l', 'ද': 'd', 'ව': 'w' , 'ශ' : 'sh',
    'භ': 'bh', 'ස': 's', 'හ': 'h', 'ය': 'y', 'ර': 'r', 'ම': 'm', 'ත': 'th', 'ඛ':'kh' , ' ': ' ', 'ඳ': 'dna'
}

pillam = {
    'ා': 'aa', 'ැ': 'A', 'ෑ': 'Aa', 'ි': 'i', 'ී': 'ii', 'ු': 'u', 'ූ': 'uu', 'ෘ': 'ru', 'ෙ': 'e', 'ේ': 'ee', 'ෛ': 'ai',
    'ො': 'o', 'ෝ': 'oo', 'ෞ': 'au',
    '්‍ය': 'ya', '්‍ර': 'ra' , '්': ' '
}

vowels = ['්', 'ඔ', 'එ', 'ඉ', 'ඊ', 'අ', 'ආ']

sinhala_unicode_mapping_1 = {
    'අ': 'a', 'ආ': 'aa', 'ඇ': 'A', 'ඈ': 'Aa', 'ඉ': 'i', 'ඊ': 'ii', 'උ': 'u', 'ඌ': 'uu', 'ඍ': 'Ru',
    'ඎ': 'Ru', 'එ': 'e', 'ඒ': 'ee', 'ඓ': 'ai', 'ඔ': 'o', 'ඕ': 'oo', 'ඖ': 'au',
    'ක': 'ka', 'කා': 'kaa', 'කැ': 'kA', 'කෑ': 'kAa', 'කි': 'ki', 'කී': 'kii', 'කු': 'ku', 'කූ': 'kuu', 'කෘ': 'kru',
    'කෙ': 'ke', 'කේ': 'kee', 'කෛ': 'kai', 'කො': 'ko', 'කෝ': 'koo', 'කෞ': 'kau', 'කෲ': 'kruu', 'ක්‍ය': 'kya', 'ක්‍ර': 'kra',
    'ග': 'ga', 'ගා': 'gaa', 'ගැ': 'gA', 'ගෑ': 'gAa', 'ගි': 'gi', 'ගී': 'gii', 'ගු': 'gu', 'ගූ': 'guu', 'ගෘ': 'guru',
    'ගෙ': 'ge', 'ගේ': 'gee', 'ගෛ': 'gai', 'ගො': 'go', 'ගෝ': 'goo', 'ගෞ': 'gau', 'ග්‍ය': 'gya', 'ග්‍ර': 'gra',
    'ච': 'cha', 'චා': 'chaa', 'චැ': 'chA', 'චෑ': 'chAa', 'චි': 'chi', 'චී': 'chii', 'චු': 'chu', 'චූ': 'chuu',
    'චෙ': 'che', 'චේ': 'chee', 'චෛ': 'chai', 'චො': 'cho', 'චෝ': 'choo', 'චෞ': 'chau', 'ච්‍ය': 'chya', 'ච්‍ර': 'chra',
    'ජ': 'ja', 'ජා': 'jaa', 'ජැ': 'jA', 'ජෑ': 'jAa', 'ජි': 'ji', 'ජී': 'jii', 'ජු': 'ju', 'ජූ': 'juu', 'කෘ': 'jru',
    'ජෙ': 'je', 'ජේ': 'jee', 'ජෛ': 'jai', 'ජො': 'jo', 'ජෝ': 'joo', 'ජෞ': 'jau', 'ජ්‍ය': 'jya', 'ජ්‍ර': 'jra',
    'ට': 'ta', 'ටා': 'taa', 'ටැ': 'tA', 'ටෑ': 'tAa', 'ටි': 'ti', 'ටී': 'tii', 'ටු': 'tu', 'ටූ': 'tuu', 'කෘ': 'tru',
    'ටෙ': 'te', 'ටේ': 'tee', 'ටෛ': 'tai', 'ටො': 'to', 'ටෝ': 'too', 'ටෞ': 'tau', 'ටඃ': 'taH', 'ට්‍ය': 'tya', 'ට්‍ර': 'tra',
    'ඩ': 'da', 'කා': 'daa', 'ඩැ': 'dA', 'ඩෑ': 'dAa', 'ඩි': 'di', 'ඩී': 'dii', 'ඩු': 'du', 'ඩූ': 'duu', 'ඩෘ': 'dru',
    'ඩෙ': 'de', 'ඩේ': 'dee', 'ඩෛ': 'dai', 'ඩො': 'do', 'ඩෝ': 'doo', 'ඩෞ': 'dau', 'ඩ්‍ය': 'dya', 'ඩ්‍ර': 'dra',
    'න': 'na', 'නා': 'naa', 'නැ': 'nA', 'නෑ': 'nAa', 'නි': 'ni', 'නී': 'nii', 'නු': 'nu', 'නූ': 'nuu', 'නෘ': 'nru',
    'නෙ': 'ne', 'නේ': 'nee', 'නෛ': 'nai', 'නො': 'no', 'නෝ': 'noo', 'නෞ': 'nau', 'න්‍ය': 'nya', 'න්‍ර': 'nra',
    'ප': 'pa', 'පා': 'paa', 'පැ': 'pA', 'පෑ': 'pAa', 'පි': 'pi', 'පී': 'pii', 'පු': 'pu', 'පූ': 'puu', 'පෘ': 'pru',
    'පෙ': 'pe', 'පේ': 'pee', 'පෛ': 'pai', 'පො': 'po', 'පෝ': 'poo', 'පෞ': 'pau', 'ප්‍ය': 'pya', 'ප්‍ර': 'pra',
    'බ': 'ba', 'බා': 'baa', 'බැ': 'bA', 'බෑ': 'bAa', 'බි': 'bi', 'බී': 'bii', 'බු': 'bu', 'බූ': 'buu', 'බෘ': 'bru',
    'බෙ': 'be', 'බේ': 'bee', 'බෛ': 'bai', 'බො': 'bo', 'බෝ': 'boo', 'බෞ': 'bau', 'බ්‍ය': 'bya', 'බ්‍ර': 'bra',
    'භ': 'bha', 'භා': 'bhaa', 'භැ': 'bhA', 'භෑ': 'bhAa', 'භි': 'bhi', 'භී': 'bhii', 'භු': 'bhu', 'භූ': 'bhuu',
    'භෘ': 'bhru', 'භෙ': 'bhe', 'භේ': 'bhee', 'භෛ': 'bhai', 'භො': 'bho', 'භෝ': 'bhoo', 'භෞ': 'bhau',
    'භ්‍ය': 'bhya', 'භ්‍ර': 'bhra', 'ම': 'm',
    'ස': 'sa', 'සා': 'saa', 'සැ': 'sA', 'සෑ': 'sAa', 'සි': 'si', 'සී': 'sii', 'සු': 'su', 'සූ': 'suu', 'සෘ': 'sru',
    'සෙ': 'se', 'සේ': 'see', 'සෛ': 'sai', 'සො': 'so', 'සෝ': 'soo', 'සෞ': 'sau', 'ස්‍ය': 'sya', 'ස්‍ර': 'sra',
    'හ': 'ha', 'හා': 'haa', 'හැ': 'hA', 'හෑ': 'hAa', 'හි': 'hi', 'හී': 'hii', 'හු': 'hu', 'හූ': 'huu', 'හෘ': 'hru',
    'හෙ': 'he', 'හේ': 'hee', 'හෛ': 'hai', 'හො': 'ho', 'හෝ': 'hoo', 'හෞ': 'hau', 'හ්‍ය': 'hya', 'හ්‍ර': 'hra',
    'යා': 'yaa', 'යැ': 'yA', 'යෑ': 'yAa', 'යි': 'yi', 'යී': 'yii', 'යු': 'yu', 'යූ': 'yuu', 'යෘ': 'yru', 'යෙ': 'ye',
    'යේ': 'yee', 'යෛ': 'yai', 'යො': 'yo', 'යෝ': 'yoo', 'යෞ': 'yau',
    'රා': 'raa', 'රැ': 'rA', 'රෑ': 'rAa', 'රි': 'ri', 'රී': 'rii', 'රු': 'ru', 'රූ': 'ruu', 'රෘ': 'rru', 'රෙ': 're',
    'රේ': 'ree', 'රෛ': 'rai', 'රො': 'ro', 'රෝ': 'roo', 'රෞ': 'rau',
    'ා': 'aa', 'ැ': 'A', 'ෑ': 'Aa', 'ි': 'i', 'ී': 'ii', 'ු': 'u', 'ූ': 'uu', 'ෘ': 'ru', 'ෙ': 'e', 'ේ': 'ee', 'ෛ': 'ai',
    'ො': 'o', 'ෝ': 'oo', 'ෞ': 'au',
    '්‍ය': 'ya', '්‍ර': 'ra'
}

==> siconv-0.1.1.7.tar.gz: siconv-0.1.1.7/siconv/util_array.py <==
charactors = {
    'අ': 'a', 'ආ': 'aa', 'ඉ': 'i', 'ඊ': 'ii', 'උ': 'u', 'ඍ': 'Ru', 'එ': 'e', 'ඔ': 'o', 'ක': 'k', 'ග': 'g', 'ච': 'ch',
    'ජ': 'j', 'ට': 't', 'ඩ': 'd', 'න': 'n', 'ප': 'p', 'බ': 'b', 'ල': 'l', 'ද': 'd', 'ව': 'w', 'ශ': 'sh',
    'භ': 'bh', 'ස': 's', 'හ': 'h', 'ය': 'y', 'ර': 'r', 'ම': 'm', 'ත': 'th', 'ඛ': 'kh', ' ': ' ', 'ඳ': 'dn',
    'උ': 'u', 'ඌ': 'uu', 'ඕ': 'oo', 'ඔ': 'o', 'ඖ': 'au', 'ඞ': 'ng', 'ඟ': 'gn', 'ඡ': 'chh', 'ඣ': 'jh',
    'ඍ': 'R', 'ඎ': 'Ru', 'ඏ': 'A', 'ඐ': 'aa', 'ෆ': 'fa',
    'ච': 'ch', 'ජ': 'j', 'ඩ': 'd', 'ළ': 'L', 'ණ': 'N', 'ධ': 'dhh', 'ඤ': 'zk', 'ඥ': 'zh',
    'ෂ': 'S', 'හෝ': 'Sh', 'ෆ': 'a', 'ඹ': 'B', 'ළු': 'L', 'ඟ': 'zg', 'ඦ': 'zja', 'ඬ': 'zd', 'හෝ': 'q',
    'ඥ': 'zh', 'ය': 'y', 'හෝ': 'A', 'හෝ': 'o', 'හෝ': 'v', 'හෝ': 'f', 'හෝ': 'Sh'
}


pillam = {
    'ා': 'aa', 'ැ': 'A', 'ෑ': 'Aa', 'ි': 'i', 'ී': 'ii', 'ු': 'u', 'ූ': 'uu', 'ෘ': 'ru', 'ෙ': 'e', 'ේ': 'ee', 'ෛ': 'ai',
    'ො': 'o', 'ෝ': 'oo', 'ෞ': 'au',
    '්‍ය': 'ya', '්‍ර': 'ra' , '්': ' '
}

vowels = ['්', 'ඔ', 'එ', 'ඉ', 'ඊ', 'අ', 'ආ', 'උ', 'ඌ']

sinhala_unicode_mapping_1 = {
    'අ': 'a', 'ආ': 'aa', 'ඇ': 'A', 'ඈ': 'Aa', 'ඉ': 'i', 'ඊ': 'ii', 'උ': 'u', 'ඌ': 'uu', 'ඍ': 'Ru',
    'ඎ': 'Ru', 'එ': 'e', 'ඒ': 'ee', 'ඓ': 'ai', 'ඔ': 'o', 'ඕ': 'oo', 'ඖ': 'au',
    'ක': 'ka', 'කා': 'kaa', 'කැ': 'kA', 'කෑ': 'kAa', 'කි': 'ki', 'කී': 'kii', 'කු': 'ku', 'කූ': 'kuu', 'කෘ': 'kru',
    'කෙ': 'ke', 'කේ': 'kee', 'කෛ': 'kai', 'කො': 'ko', 'කෝ': 'koo', 'කෞ': 'kau', 'කෲ': 'kruu', 'ක්‍ය': 'kya', 'ක්‍ර': 'kra',
    'ග': 'ga', 'ගා': 'gaa', 'ගැ': 'gA', 'ගෑ': 'gAa', 'ගි': 'gi', 'ගී': 'gii', 'ගු': 'gu', 'ගූ': 'guu', 'ගෘ': 'guru',
    'ගෙ': 'ge', 'ගේ': 'gee', 'ගෛ': 'gai', 'ගො': 'go', 'ගෝ': 'goo', 'ගෞ': 'gau', 'ග්‍ය': 'gya', 'ග්‍ර': 'gra',
    'ච': 'cha', 'චා': 'chaa', 'චැ': 'chA', 'චෑ': 'chAa', 'චි': 'chi', 'චී': 'chii', 'චු': 'chu', 'චූ': 'chuu',
    'චෙ': 'che', 'චේ': 'chee', 'චෛ': 'chai', 'චො': 'cho', 'චෝ': 'choo', 'චෞ': 'chau', 'ච්‍ය': 'chya', 'ච්‍ර': 'chra',
    'ජ': 'ja', 'ජා': 'jaa', 'ජැ': 'jA', 'ජෑ': 'jAa', 'ජි': 'ji', 'ජී': 'jii', 'ජු': 'ju', 'ජූ': 'juu', 'කෘ': 'jru',
    'ජෙ': 'je', 'ජේ': 'jee', 'ජෛ': 'jai', 'ජො': 'jo', 'ජෝ': 'joo', 'ජෞ': 'jau', 'ජ්‍ය': 'jya', 'ජ්‍ර': 'jra',
    'ට': 'ta', 'ටා': 'taa', 'ටැ': 'tA', 'ටෑ': 'tAa', 'ටි': 'ti', 'ටී': 'tii', 'ටු': 'tu', 'ටූ': 'tuu', 'කෘ': 'tru',
    'ටෙ': 'te', 'ටේ': 'tee', 'ටෛ': 'tai', 'ටො': 'to', 'ටෝ': 'too', 'ටෞ': 'tau', 'ටඃ': 'taH', 'ට්‍ය': 'tya', 'ට්‍ර': 'tra',
    'ඩ': 'da', 'කා': 'daa', 'ඩැ': 'dA', 'ඩෑ': 'dAa', 'ඩි': 'di', 'ඩී': 'dii', 'ඩු': 'du', 'ඩූ': 'duu', 'ඩෘ': 'dru',
    'ඩෙ': 'de', 'ඩේ': 'dee', 'ඩෛ': 'dai', 'ඩො': 'do', 'ඩෝ': 'doo', 'ඩෞ': 'dau', 'ඩ්‍ය': 'dya', 'ඩ්‍ර': 'dra',
    'න': 'na', 'නා': 'naa', 'නැ': 'nA', 'නෑ': 'nAa', 'නි': 'ni', 'නී': 'nii', 'නු': 'nu', 'නූ': 'nuu', 'නෘ': 'nru',
    'නෙ': 'ne', 'නේ': 'nee', 'නෛ': 'nai', 'නො': 'no', 'නෝ': 'noo', 'නෞ': 'nau', 'න්‍ය': 'nya', 'න්‍ර': 'nra',
    'ප': 'pa', 'පා': 'paa', 'පැ': 'pA', 'පෑ': 'pAa', 'පි': 'pi', 'පී': 'pii', 'පු': 'pu', 'පූ': 'puu', 'පෘ': 'pru',
    'පෙ': 'pe', 'පේ': 'pee', 'පෛ': 'pai', 'පො': 'po', 'පෝ': 'poo', 'පෞ': 'pau', 'ප්‍ය': 'pya', 'ප්‍ර': 'pra',
    'බ': 'ba', 'බා': 'baa', 'බැ': 'bA', 'බෑ': 'bAa', 'බි': 'bi', 'බී': 'bii', 'බු': 'bu', 'බූ': 'buu', 'බෘ': 'bru',
    'බෙ': 'be', 'බේ': 'bee', 'බෛ': 'bai', 'බො': 'bo', 'බෝ': 'boo', 'බෞ': 'bau', 'බ්‍ය': 'bya', 'බ්‍ර': 'bra',
    'භ': 'bha', 'භා': 'bhaa', 'භැ': 'bhA', 'භෑ': 'bhAa', 'භි': 'bhi', 'භී': 'bhii', 'භු': 'bhu', 'භූ': 'bhuu',
    'භෘ': 'bhru', 'භෙ': 'bhe', 'භේ': 'bhee', 'භෛ': 'bhai', 'භො': 'bho', 'භෝ': 'bhoo', 'භෞ': 'bhau',
    'භ්‍ය': 'bhya', 'භ්‍ර': 'bhra', 'ම': 'm',
    'ස': 'sa', 'සා': 'saa', 'සැ': 'sA', 'සෑ': 'sAa', 'සි': 'si', 'සී': 'sii', 'සු': 'su', 'සූ': 'suu', 'සෘ': 'sru',
    'සෙ': 'se', 'සේ': 'see', 'සෛ': 'sai', 'සො': 'so', 'සෝ': 'soo', 'සෞ': 'sau', 'ස්‍ය': 'sya', 'ස්‍ර': 'sra',
    'හ': 'ha', 'හා': 'haa', 'හැ': 'hA', 'හෑ': 'hAa', 'හි': 'hi', 'හී': 'hii', 'හු': 'hu', 'හූ': 'huu', 'හෘ': 'hru',
    'හෙ': 'he', 'හේ': 'hee', 'හෛ': 'hai', 'හො': 'ho', 'හෝ': 'hoo', 'හෞ': 'hau', 'හ්‍ය': 'hya', 'හ්‍ර': 'hra',
    'යා': 'yaa', 'යැ': 'yA', 'යෑ': 'yAa', 'යි': 'yi', 'යී': 'yii', 'යු': 'yu', 'යූ': 'yuu', 'යෘ': 'yru', 'යෙ': 'ye',
    'යේ': 'yee', 'යෛ': 'yai', 'යො': 'yo', 'යෝ': 'yoo', 'යෞ': 'yau',
    'රා': 'raa', 'රැ': 'rA', 'රෑ': 'rAa', 'රි': 'ri', 'රී': 'rii', 'රු': 'ru', 'රූ': 'ruu', 'රෘ': 'rru', 'රෙ': 're',
    'රේ': 'ree', 'රෛ': 'rai', 'රො': 'ro', 'රෝ': 'roo', 'රෞ': 'rau',
    'ා': 'aa', 'ැ': 'A', 'ෑ': 'Aa', 'ි': 'i', 'ී': 'ii', 'ු': 'u', 'ූ': 'uu', 'ෘ': 'ru', 'ෙ': 'e', 'ේ': 'ee', 'ෛ': 'ai',
    'ො': 'o', 'ෝ': 'oo', 'ෞ': 'au',
    '්‍ය': 'ya', '්‍ර': 'ra'
}
